==> haskell-hslua-aeson-2.1.0-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-aeson
version:              2.1.0
visibility:           public
id:                   hslua-aeson-2.1.0-EpHQjxzQ8eZ5dd1tgUFzGV
key:                  hslua-aeson-2.1.0-EpHQjxzQ8eZ5dd1tgUFzGV
license:              MIT
copyright:            © 2017–2021 Albert Krewinkel
maintainer:           Albert Krewinkel <albert+hslua@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  a270f7231ccaec67fbd7f0886d80210b
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-aeson-2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-aeson-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.1.0-EpHQjxzQ8eZ5dd1tgUFzGV
depends:
    aeson-1.5.6.0-Fb9ZMAIDiHqHU60EYqqQrU base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.4.0.2-A7cEvE0oiq92I0kqqbT0NC
    hslua-core-2.1.0-3sUoI5AQ6Yj7ZFBnlvSQdo
    hslua-marshalling-2.1.0-8xRSLM9nCCXLP2QlJ33N2H mtl-2.2.2
    scientific-0.3.7.0-BGDOHpeWZcM6hFLsiwwQPU text-1.2.5.0
    unordered-containers-0.2.19.1-C9nTlDD6Q7DH9RSyMbZGKJ
    vector-0.12.3.1-35O4ef8MZDE9Y9qFX9F3Ug

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-aeson-2.1.0-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hslua-aeson
version:              2.1.0
visibility:           public
id:                   hslua-aeson-2.1.0-GQmzxLAtDsfEsPPmS0zKsY
key:                  hslua-aeson-2.1.0-GQmzxLAtDsfEsPPmS0zKsY
license:              MIT
copyright:            © 2017–2021 Albert Krewinkel
maintainer:           Albert Krewinkel <albert+hslua@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  003e2b5c1b38af09bf754547acd85ac7
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.0.2/site-local/hslua-aeson-2.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/hslua-aeson-2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.1.0-GQmzxLAtDsfEsPPmS0zKsY
depends:
    aeson-1.5.6.0-GZUW0RX6wR0GNyId2zbUZx base-4.15.1.0
    bytestring-0.10.12.1 containers-0.6.4.1
    hashable-1.4.0.2-A7cEvE0oiq92I0kqqbT0NC
    hslua-core-2.1.0-3FRz0n2z0ob6x88v7baw1R
    hslua-marshalling-2.1.0-2zNQAwLI8YxHgfMiPmX9JY mtl-2.2.2
    scientific-0.3.7.0-BGDOHpeWZcM6hFLsiwwQPU text-1.2.5.0
    unordered-containers-0.2.19.1-F6flbRdcGQH5ESgepmhKFP
    vector-0.12.3.1-35O4ef8MZDE9Y9qFX9F3Ug

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
